@@ -1,5 +1,6 @@
 # Copyright 2020-present NAVER Corp. Under BSD 3-clause license
-
+import logging
+from tqdm import tqdm
 import os
 import os.path as path
 from random import randint
@@ -7,9 +8,14 @@ from typing import Dict
 import numpy as np
 
 import kapture
+from .csv import kapture_linesep
 from .features import image_keypoints_from_file
 
-PLY_HEADER_TEMPLATE = '\n'.join([
+
+logger = logging.getLogger('ply')
+
+
+PLY_HEADER_TEMPLATE = kapture_linesep.join([
     'ply',
     'format ascii 1.0',
     'element vertex {nb_vertex}',
@@ -50,7 +56,7 @@ def get_axis_in_world(
         [length, 0, 0],  # X
         [0, length, 0],  # Y
         [0, 0, length],  # Z
-    ])
+    ], dtype=np.float)
     return pose_device_from_world.inverse().transform_points(sensor_axis)
 
 
@@ -64,7 +70,7 @@ def header_to_ply_stream(stream, nb_vertex: int = 0, nb_edges: int = 0) -> None:
     """
     stream.write(PLY_HEADER_TEMPLATE.format(nb_vertex=nb_vertex,
                                             nb_edges=nb_edges))
-    stream.write('\n')
+    stream.write(kapture_linesep)
 
 
 def rig_to_ply_stream(stream, rig: Dict[str, kapture.PoseTransform], axis_length: float = 1.) -> None:
@@ -96,10 +102,10 @@ def rig_to_ply_stream(stream, rig: Dict[str, kapture.PoseTransform], axis_length
     for p3d in points_colored_list:
         line = ['{:<25}'.format(i) for i in p3d[0:3]]
         line += ['{:03}'.format(int(i)) for i in p3d[3:6]]
-        stream.write(' '.join(line) + '\n')
+        stream.write(' '.join(line) + kapture_linesep)
     for e in edges_list:
         line = ['{:2}'.format(i) for i in e]
-        stream.write(' '.join(line) + '\n')
+        stream.write(' '.join(line) + kapture_linesep)
 
 
 def rig_to_ply(filepath: str, rig: Dict[str, kapture.PoseTransform], axis_length: float = 1.) -> None:
@@ -131,15 +137,16 @@ def trajectories_to_ply_stream(stream, trajectories: kapture.Trajectories, axis_
     # create 4 points per pose: 1 for center, 3 for axis
     points_colored_list = []
     for pose_tr in pose_list:
-        axis = get_axis_in_world(pose_tr, axis_length)
+        axis = get_axis_in_world(pose_device_from_world=pose_tr, length=axis_length)
         points_colored_list += [p + AXIS_COLORS[i] for i, p in enumerate(axis.tolist())]
 
     # write points into ply
     header_to_ply_stream(stream, nb_vertex=len(points_colored_list))
-    for p3d in points_colored_list:
+    hide = logger.getEffectiveLevel() >= logging.CRITICAL
+    for p3d in tqdm(points_colored_list, disable=hide):
         line = ['{:<25}'.format(i) for i in p3d[0:3]]
         line += ['{:<4}'.format(i) for i in p3d[3:6]]
-        stream.write(' '.join(line) + '\n')
+        stream.write(' '.join(line) + kapture_linesep)
 
 
 def trajectories_to_ply(
@@ -159,7 +166,7 @@ def trajectories_to_ply(
     """
     os.makedirs(path.dirname(filepath), exist_ok=True)
     with open(filepath, 'w') as fout:
-        trajectories_to_ply_stream(fout, trajectories, axis_length)
+        trajectories_to_ply_stream(stream=fout, trajectories=trajectories, axis_length=axis_length)
 
 
 def points3d_to_stream(stream, points3d: kapture.Points3d) -> None:
@@ -172,7 +179,7 @@ def points3d_to_stream(stream, points3d: kapture.Points3d) -> None:
     header_to_ply_stream(stream, nb_vertex=len(points3d))
     for p3d in points3d:
         line = ['{:20}'.format(i) for i in p3d[0:3]] + ['{:03d}'.format(int(i)) for i in p3d[3:6]]
-        stream.write('  '.join(line) + '\n')
+        stream.write('  '.join(line) + kapture_linesep)
 
 
 def points3d_to_ply(filepath: str, points3d: kapture.Points3d) -> None:
@@ -187,6 +194,46 @@ def points3d_to_ply(filepath: str, points3d: kapture.Points3d) -> None:
         points3d_to_stream(f, points3d)
 
 
+def local_points3d_to_stream(
+        stream,
+        points3d: np.ndarray,
+        transform_world_from_local: kapture.PoseTransform
+) -> None:
+    """
+    Writes the 3D points from a local coordinate system into world into a stream.
+
+    :param stream: an open stream to write to
+    :param points3d: input 3d points as a Nx3 numpy array
+    :param transform_world_from_local: transformation
+    """
+    # sanity check
+    if not isinstance(points3d, np.ndarray) or points3d.shape[1] != 3:
+        raise TypeError('expect 3d points as a numpy array.')
+
+    header_to_ply_stream(stream, nb_vertex=points3d.shape[0])
+    for p3d_local in points3d:
+        p3d_world = transform_world_from_local.transform_points(p3d_local)
+        line = ['{:20}'.format(i) for i in p3d_world]
+        stream.write('  '.join(line) + kapture_linesep)
+
+
+def local_points3d_to_ply(
+        filepath: str,
+        points3d: np.ndarray,
+        transform_world_from_local: kapture.PoseTransform
+) -> None:
+    """
+    Writes 3D points into ply file.
+
+    :param filepath: ply file path.
+    :param points3d: input 3d points as a Nx3 numpy array
+    :param transform_world_from_local: transformation
+    """
+    os.makedirs(path.dirname(filepath), exist_ok=True)
+    with open(filepath, 'w') as f:
+        local_points3d_to_stream(f, points3d, transform_world_from_local)
+
+
 def image_keypoints_to_stream(stream, image_keypoints: np.array) -> None:
     """
     Plots image keypoints onto a 2D plane. Use random colors.
@@ -198,7 +245,7 @@ def image_keypoints_to_stream(stream, image_keypoints: np.array) -> None:
     for kpt in image_keypoints:
         coords = kpt[0:2]
         line = ['{:20}'.format(i) for i in coords] + ['0.0'] + ['{:03d}'.format(randint(0, 255)) for _ in range(3)]
-        stream.write('  '.join(line) + '\n')
+        stream.write('  '.join(line) + kapture_linesep)
 
 
 def image_keypoints_to_ply(ply_filepath: str, image_keypoints_filepath: str, keypoint_dtype, keypoint_dsize) -> None:
