@@ -4,5 +4,5 @@
 Additional utility functions and classes used by kapture but not specific to it.
 """
 
-from .Collections import AutoEnum
-from .paths import path_secure, populate_files_in_dirpath
+from .Collections import AutoEnum  # noqa: F401
+from .paths import path_secure, populate_files_in_dirpath  # noqa: F401
