@@ -13,21 +13,23 @@ import PIL
 from PIL import Image
 
 # kapture
-import path_to_kapture
+import path_to_kapture  # noqa: F401
 import kapture
 import kapture.utils.logging
 from kapture.io.structure import delete_existing_kapture_files
-from kapture.io.csv import kapture_to_dir
+from kapture.io.csv import kapture_to_dir, sensors_from_file
 from kapture.utils.paths import path_secure
 from kapture.io.records import TransferAction, import_record_data_from_dir_auto
 
 logger = logging.getLogger('image_folder')
 
 
-def import_image_folder(images_path: str,
-                        kapture_path: str,
-                        force_overwrite_existing: bool = False,
-                        images_import_method: TransferAction = TransferAction.skip) -> None:
+def import_image_folder(
+        images_path: str,
+        kapture_path: str,
+        force_overwrite_existing: bool = False,
+        images_import_method: TransferAction = TransferAction.skip
+) -> None:
     """
     Imports the images of a folder to a kapture. This creates only images and cameras.
 
@@ -39,14 +41,22 @@ def import_image_folder(images_path: str,
     os.makedirs(kapture_path, exist_ok=True)
     delete_existing_kapture_files(kapture_path, force_erase=force_overwrite_existing)
 
-    cameras = kapture.Sensors()
     images = kapture.RecordsCamera()
 
-    file_list = [os.path.relpath(os.path.join(dirpath, filename), images_path)
+    file_list = [path.relpath(path.join(dirpath, filename), images_path)
                  for dirpath, dirs, filenames in os.walk(images_path)
                  for filename in filenames]
     file_list = sorted(file_list)
 
+    try:
+        sensors_filepath = path.join(images_path, 'sensors.txt')
+        sensors = sensors_from_file(sensors_filepath)
+        sensors_given = True
+    except OSError:
+        logger.info('image folder has no extra sensor info')
+        sensors = kapture.Sensors()
+        sensors_given = False
+
     logger.info('starting conversion...')
     for n, filename in enumerate(file_list):
         # test if file is a valid image
@@ -60,9 +70,23 @@ def import_image_folder(images_path: str,
             logger.info(f'Skipping invalid image file {filename}')
             continue
 
-        camera_id = f'sensor{n}'
+        if sensors_given:
+            if len(sensors) == 1:
+                # in case of single camera, just take the name from sensors.txt
+                camera_id = list(sensors.keys())[0]
+            else:
+                # guess sensor_id from dirname
+                camera_id = path.dirname(path.join(images_path, filename)).split(os.sep)[-1]
+
+            if camera_id not in sensors:
+                logger.critical(f'camera {camera_id} is not found in sensors.txt')
+                raise KeyError(f'camera {camera_id} is not found in sensors.txt')
+
+        else:
+            camera_id = f'sensor{n}'
+            sensors[camera_id] = kapture.Camera(kapture.CameraType.UNKNOWN_CAMERA, model_params)
+
         images[(n, camera_id)] = path_secure(filename)  # don't forget windows
-        cameras[camera_id] = kapture.Camera(kapture.CameraType.UNKNOWN_CAMERA, model_params)
 
     # import (copy) image files.
     logger.info('import image files ...')
@@ -70,7 +94,7 @@ def import_image_folder(images_path: str,
     import_record_data_from_dir_auto(images_path, kapture_path, filename_list, images_import_method)
 
     # pack into kapture format
-    imported_kapture = kapture.Kapture(sensors=cameras, records_camera=images)
+    imported_kapture = kapture.Kapture(sensors=sensors, records_camera=images)
     logger.info('writing imported data...')
     kapture_to_dir(kapture_path, imported_kapture)
 
