@@ -11,13 +11,13 @@ import logging
 from os import path
 import sys
 # kapture
-import path_to_kapture  # enables import kapture
+import path_to_kapture  # enables import kapture  # noqa: F401
 import kapture.io.csv as kcsv
 import kapture.utils.logging
 
 # rosbag
 try:
-    import rosbag
+    import rosbag  # noqa: F401
     from kapture.converter.ros_tools.import_rosbag import RosBagImporter
 
     has_rosbag = True
@@ -122,7 +122,7 @@ def import_rosbag_command_line() -> None:
 
 if __name__ == '__main__':
     if not has_rosbag:
-        logger.fatal(f"You don't have ROS or import_rosbag installed")
+        logger.fatal("You don't have ROS or import_rosbag installed")
         sys.exit(-1)
     try:
         import_rosbag_command_line()
